@@ -1,4 +1,4 @@
-join_rows <- function(x_key, y_key, type = c("inner", "left", "right", "full"), na_equal = TRUE) {
+join_rows <- function(x_key, y_key, type = c("inner", "left", "right", "full"), na_equal = TRUE, error_call = caller_env()) {
   type <- arg_match(type)
 
   # Find matching rows in y for each row in x
@@ -10,11 +10,12 @@ join_rows <- function(x_key, y_key, type = c("inner", "left", "right", "full"),
       x_name <- sub(rx, "", cnd$x_arg)
       y_name <- sub(rx, "", cnd$y_arg)
 
-      abort(c(
+      bullets <- c(
         glue("Can't join on `x${x_name}` x `y${y_name}` because of incompatible types."),
         i = glue("`x${x_name}` is of type <{x_type}>>.", x_type = vec_ptype_full(cnd$x)),
         i = glue("`y${y_name}` is of type <{y_type}>>.", y_type = vec_ptype_full(cnd$y))
-      ))
+      )
+      abort(bullets, call = error_call)
     }
   )
 
